==> timsac_1.3.6.tar.gz: timsac/src/autcorf.f <==
      SUBROUTINE AUTCORF(X,N,CXX,CN,LAGH1,XMEAN)
C
      INCLUDE 'timsac_f.h'
C
C     PROGRAM 5.1.1   AUTO CORRELATION
C-----------------------------------------------------------------------
C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
C         TOKYO
C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
C-----------------------------------------------------------------------
C     THIS PROGRAM REQUIRES FOLLOWING INPUTS:
C     N: LENGTH OF DATA
C     LAGH: MAXIMUM LAG
C     DFORM: INPUT FORMAT SPECIFICATION STATEMENT IN ONE CARD,
C     FOR EXAMPLE
C     (8F10.4)
C     (X(I),I=1,N): ORIGINAL DATA.
C     THE OUTPUTS ARE AUTOCOVARIANCES (CXX(I); I=0,LAGH) AND
C     AUTO CORRELATIONS (NORMALIZED COVARIANCES).
C
cc      !DEC$ ATTRIBUTES DLLEXPORT :: AUTCORF
C
cxx      IMPLICIT REAL*8 (A-H,O-Z)
c      DIMENSION X(5000),CXX(1001),CN(1001)
c	 REAL*4 DFORM
c      DIMENSION  DFORM(20)
cxx      DIMENSION X(N),X1(N),CXX(LAGH1),CN(LAGH1)
      INTEGER :: N, LAGH1
      REAL(8) :: X(N), CXX(LAGH1), CN(LAGH1), XMEAN
      REAL(8) :: X1(N), CX0
C
C     INPUT / OUTPUT DATA FILE OPEN
c	CHARACTER(100) DFNAM
c	CALL SETWND
c	DFNAM='autcor.out'
c      CALL FLOPN3(DFNAM,NFL)
c      IF (NFL.EQ.0) GO TO 999
C     INITIAL CONDITION INPUT AND PRINT OUT
c      READ(5,1) N,LAGH
c      WRITE(6,50)
c      WRITE(6,51)
c      WRITE(6,52) N,LAGH
C     INPUT FORMAT SPECIFICATION
c      READ(5,4) (DFORM(I),I=1,20)
c    4 FORMAT(20A4)
C     ORIGINAL DATA INPUT AND PRINT OUT
c      READ(5,DFORM) (X(I),I=1,N)
c      WRITE(6,53)
c      WRITE(6,54)
c      DO 220 I=1,N
c  220 WRITE(6,55) I,X(I)
      DO 220 I=1,N
cxx  220 X1(I)=X(I)
      X1(I)=X(I)
  220 CONTINUE
C     MEAN DELETION
      CALL DMEADL(X1,N,XMEAN)
C     AUTO COVARIANCE COMPUTATION
c      LAGH1=LAGH+1
      CALL CROSCO(X1,X1,N,CXX,LAGH1)
C     NORMALIZATION
      CX0=CXX(1)
      CALL CORNOM(CXX,CN,LAGH1,CX0,CX0)
C     AUTO COVARIANCE PRINT OUT
c      WRITE(6,162) N,LAGH,XMEAN
c      WRITE(6,163)
c      CALL PRCOL2(CXX,CN,1,LAGH1,1)
C     AUTO COVARIANCE PUNCH OUT
c      WRITE(7,1) N,LAGH
c      WRITE(7,2) (CXX(I),I=1,LAGH1)
c	CALL FLCLS3(NFL)
c  999 CONTINUE
c    1 FORMAT(10I5)
c    2 FORMAT(4D20.10)
c   50 FORMAT(1H ,13HPROGRAM 5.1.1,3X,16HAUTO CORRELATION)
c   51 FORMAT(1H ,17HINITIAL CONDITION)
c   52 FORMAT(1H ,2HN=,I5,5X,5HLAGH=,I5)
c   53 FORMAT(1H ,13HORIGINAL DATA)
c   54 FORMAT(1H ,4X,1HI,6X,4HX(I))
c   55 FORMAT(1H ,I5,2X,F10.4)
cCC  162 FORMAT(//1H ,14HAUTOCOVARIANCE,5X,6HCXX(I),5X,2HN=,I5,5X,5HLAGH=,I
c  162 FORMAT(1H ,14HAUTOCOVARIANCE,5X,6HCXX(I),5X,2HN=,I5,5X,5HLAGH=,I
c     A5,5X,5HMEAN=,D15.5)
c  163 FORMAT(1H ,4X,1HI,5X,6HCXX(I),8X,10HNORMALIZED)
      RETURN
      END

==> timsac_1.3.8.tar.gz: timsac/src/autcorf.f <==
      SUBROUTINE AUTCORF(X,N,CXX,CN,LAGH1,XMEAN)
C
      INCLUDE 'timsac.h'
C
C     PROGRAM 5.1.1   AUTO CORRELATION
C-----------------------------------------------------------------------
C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
C         TOKYO
C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
C-----------------------------------------------------------------------
C     THIS PROGRAM REQUIRES FOLLOWING INPUTS:
C     N: LENGTH OF DATA
C     LAGH: MAXIMUM LAG
C     DFORM: INPUT FORMAT SPECIFICATION STATEMENT IN ONE CARD,
C     FOR EXAMPLE
C     (8F10.4)
C     (X(I),I=1,N): ORIGINAL DATA.
C     THE OUTPUTS ARE AUTOCOVARIANCES (CXX(I); I=0,LAGH) AND
C     AUTO CORRELATIONS (NORMALIZED COVARIANCES).
C
cc      !DEC$ ATTRIBUTES DLLEXPORT :: AUTCORF
C
cxx      IMPLICIT REAL*8 (A-H,O-Z)
c      DIMENSION X(5000),CXX(1001),CN(1001)
c	 REAL*4 DFORM
c      DIMENSION  DFORM(20)
cxx      DIMENSION X(N),X1(N),CXX(LAGH1),CN(LAGH1)
      INTEGER N, LAGH1
      DOUBLE PRECISION X(N), CXX(LAGH1), CN(LAGH1), XMEAN
c local
      DOUBLE PRECISION X1(N), CX0
C
C     INPUT / OUTPUT DATA FILE OPEN
c	CHARACTER(100) DFNAM
c	CALL SETWND
c	DFNAM='autcor.out'
c      CALL FLOPN3(DFNAM,NFL)
c      IF (NFL.EQ.0) GO TO 999
C     INITIAL CONDITION INPUT AND PRINT OUT
c      READ(5,1) N,LAGH
c      WRITE(6,50)
c      WRITE(6,51)
c      WRITE(6,52) N,LAGH
C     INPUT FORMAT SPECIFICATION
c      READ(5,4) (DFORM(I),I=1,20)
c    4 FORMAT(20A4)
C     ORIGINAL DATA INPUT AND PRINT OUT
c      READ(5,DFORM) (X(I),I=1,N)
c      WRITE(6,53)
c      WRITE(6,54)
c      DO 220 I=1,N
c  220 WRITE(6,55) I,X(I)
      DO 220 I=1,N
cxx  220 X1(I)=X(I)
      X1(I)=X(I)
  220 CONTINUE
C     MEAN DELETION
      CALL DMEADL(X1,N,XMEAN)
C     AUTO COVARIANCE COMPUTATION
c      LAGH1=LAGH+1
      CALL CROSCO(X1,X1,N,CXX,LAGH1)
C     NORMALIZATION
      CX0=CXX(1)
      CALL CORNOM(CXX,CN,LAGH1,CX0,CX0)
C     AUTO COVARIANCE PRINT OUT
c      WRITE(6,162) N,LAGH,XMEAN
c      WRITE(6,163)
c      CALL PRCOL2(CXX,CN,1,LAGH1,1)
C     AUTO COVARIANCE PUNCH OUT
c      WRITE(7,1) N,LAGH
c      WRITE(7,2) (CXX(I),I=1,LAGH1)
c	CALL FLCLS3(NFL)
c  999 CONTINUE
c    1 FORMAT(10I5)
c    2 FORMAT(4D20.10)
c   50 FORMAT(1H ,13HPROGRAM 5.1.1,3X,16HAUTO CORRELATION)
c   51 FORMAT(1H ,17HINITIAL CONDITION)
c   52 FORMAT(1H ,2HN=,I5,5X,5HLAGH=,I5)
c   53 FORMAT(1H ,13HORIGINAL DATA)
c   54 FORMAT(1H ,4X,1HI,6X,4HX(I))
c   55 FORMAT(1H ,I5,2X,F10.4)
cCC  162 FORMAT(//1H ,14HAUTOCOVARIANCE,5X,6HCXX(I),5X,2HN=,I5,5X,5HLAGH=,I
c  162 FORMAT(1H ,14HAUTOCOVARIANCE,5X,6HCXX(I),5X,2HN=,I5,5X,5HLAGH=,I
c     A5,5X,5HMEAN=,D15.5)
c  163 FORMAT(1H ,4X,1HI,5X,6HCXX(I),8X,10HNORMALIZED)
      RETURN
      END
